pub enum SemanticTokenType {
Known(SemanticTokenTypeEnum),
Custom(Cow<'static, str>),
}Expand description
A set of predefined token types. This set is not fixed and clients can specify additional token types via the corresponding client capabilities.
@since 3.16.0
Variants
Known(SemanticTokenTypeEnum)
Custom(Cow<'static, str>)
Implementations
Sourceimpl SemanticTokenType
impl SemanticTokenType
pub const NAMESPACE: SemanticTokenType
pub const TYPE: SemanticTokenType
pub const CLASS: SemanticTokenType
pub const ENUM: SemanticTokenType
pub const INTERFACE: SemanticTokenType
pub const STRUCT: SemanticTokenType
pub const TYPE_PARAMETER: SemanticTokenType
pub const PARAMETER: SemanticTokenType
pub const VARIABLE: SemanticTokenType
pub const PROPERTY: SemanticTokenType
pub const ENUM_MEMBER: SemanticTokenType
pub const EVENT: SemanticTokenType
pub const FUNCTION: SemanticTokenType
pub const METHOD: SemanticTokenType
pub const MACRO: SemanticTokenType
pub const KEYWORD: SemanticTokenType
pub const MODIFIER: SemanticTokenType
pub const COMMENT: SemanticTokenType
pub const STRING: SemanticTokenType
pub const NUMBER: SemanticTokenType
pub const REGEXP: SemanticTokenType
pub const OPERATOR: SemanticTokenType
Sourcepub const DECORATOR: SemanticTokenType
pub const DECORATOR: SemanticTokenType
@since 3.17.0
Sourcepub const LABEL: SemanticTokenType
pub const LABEL: SemanticTokenType
@since 3.18.0
pub const fn new(tag: &'static str) -> Self
pub fn as_str(&self) -> &str