Module protocol

Module protocol 

Structs

NotificationMessage
A NotificationMessage works like an event and does not send a response back.
RequestMessage
A request message to describe a request between the client and the server. Every request starts with an internal id.
ResponseError
The error object in case a request fails.

Enums

ResponseMessage
A response message is sent as a result of a request.