pub struct ResponseError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
The error object in case a request fails.
Fields
code: i32A number indicating the error type that occurred.
message: StringA string providing a short description of the error.
data: Option<Value>A primitive or structured value that contains additional information about the error. Can be omitted.